"""
Constants
"""

PACKAGE_NAME = "aa_discord_announcements"
APP_NAME = "aa-discord-announcements"
GITHUB_URL = f"https://github.com/ppfeufer/{APP_NAME}"
DISCORD_WEBHOOK_REGEX = r"https:\/\/discord\.com\/api\/webhooks\/[\d]+\/[a-zA-Z0-9_-]+$"
INTERNAL_URL_PREFIX = (
    "-"  # All internal URLs (e.g.: ajax calls) need to start with this prefix
)
